read_map — pysm v3.0.0

pysm:docs

- Index
- Modules

### Navigation

- next »
- « previous |
- pysm v3.0.0 »
- pysm Documentation »
- read_map

# read_map

`pysm.` `read_map`(path, nside, unit=None, field=0, map_dist=None, dataurl=None)

  Wrapper of `healpy.read_map` for PySM data. This function also extracts the units from the fits HDU and applies them to the data array to form an `astropy.units.Quantity` object. This function requires that the fits file contains a TUNIT key for each populated field.

  Parameters
    pathobject `pathlib.Path`, or str

      Path of HEALPix map to be read.

    nsideint

      Resolution at which to return map. Map is read in at whatever resolution it is stored, and `healpy.ud_grade` is applied.

  Returns
    mapndarray

      Numpy array containing HEALPix map in RING ordering.